/*
 * @(#)Circle.java  1.0  20 October 2001
 *
 * Copyright 2001
 * College of Computer Science
 * Northeastern University
 * Boston, MA  02115
 *
 * This software may be used for educational purposes as long as
 * this copyright notice is retained intact at the top of all files.
 *
 * Should this software be modified, the words "Modified from 
 * Original" must be included as a comment below this notice.
 *
 * All publication rights are retained.  This software or its 
 * documentation may not be published in any media either in whole
 * or in part without explicit permission.
 *
 * Contact information:
 *   Richard Rasala    rasala@ccs.neu.edu
 *   Viera Proulx      vkp@ccs.neu.edu
 *   Jeff Raab         jmr@ccs.neu.edu
 * 
 * Telephone:          617-373-2462
 *
 * This software was created with support from Northeastern 
 * University and from NSF grant DUE-9950829.
 */

import edu.neu.ccs.*;

import java.awt.*;
import java.awt.geom.*;

//import java.text.ParseException;

/**
 * Class to handle time operations in hours and minutes.
 *
 *
 * @author Richard Rasala
 * @author
 */
public class Circle
    // implements Stringable
{

    /////////////////
    // Member Data //
    /////////////////
    
    // needs
    // radius >= 0
    // center: as coordinates
    // center: as object Point2D.Double
    
    double radius = 0;
    
    Point2D.Double center = new Point2D.Double();
    
    //////////////////
    // Constructors //
    //////////////////
    
    public Circle() {}
    
    public Circle(double radius) {
        setRadius(radius);
    }
    
    public Circle(double x, double y) {
        setLocation(x, y);
    }
     
    public Circle(Point2D point) {
        setLocation(point);
    }
     
    public Circle(double radius, double x, double y) {
        setRadius(radius);
        setLocation(x, y);
    }
    
    public Circle(double radius, Point2D point) {
        setRadius(radius);
        setLocation(point);
    }
    
    ///////////////////
    // Set Functions //
    ///////////////////
    
    public void setRadius(double radius) {
        if (radius >= 0)
            this.radius = radius;
    }
    
    public void setDiameter(double diameter) {
        setRadius(diameter / 2);
    }
    
    public void setLocation(double x, double y) {
        center.setLocation(x, y);
    }
    
    public void setLocation(Point2D point) {
        center.setLocation(point);
    }
    
    ///////////////////
    // Get Functions //
    ///////////////////
    
    
    public double getRadius() {
        return radius;
    }
    
    public double getX() {
        return center.getX();
    }
    
    public double getMinimumX() {
        return getX() - radius;
    }
    
    public double getMaximumX() {
        return getX() + radius;
    }
    
    public double getY() {
        return center.getY();
    }
    
    public double getMinimumY() {
        return getY() - radius;
    }
    
    public double getMaximumY() {
        return getY() + radius;
    }
    
    public Point2D getCenter() {
        return center;
    }
    
    public double getDiameter() {
        return 2 * radius;
    }
    
    public double getCircumference() {
        return 2 * Math.PI * radius;
    }
    
    public double getArea() {
        return Math.PI * radius * radius;
    }
    
    //////////////
    // Plotting //
    //////////////
    
    public void draw(Graphics2D g) {
        draw(g, Color.black);
    }
    
    public void fill(Graphics2D g) {
        fill(g, Color.black);
    }
    
    public void draw(Graphics2D g, Paint paint) {
        if (paint == null)
            paint = Color.black;
        
        g.setPaint(paint);
        g.draw(getEllipse());
    }
    
    public void fill(Graphics2D g, Paint paint) {
        if (paint == null)
            paint = Color.black;
        
        g.setPaint(paint);
        g.fill(getEllipse());
    }
    
    //////////////////////
    // Helper Functions //
    //////////////////////
    
    protected Ellipse2D.Double getEllipse() {
        return new Ellipse2D.Double
            (getMinimumX(), getMinimumY(), getDiameter(), getDiameter());
    }
}