/*
 * @(#)CircleTester.java  1.0  21 October 2001
 *
 * Copyright 2001
 * College of Computer Science
 * Northeastern University
 * Boston, MA  02115
 *
 * This software may be used for educational purposes as long as
 * this copyright notice is retained intact at the top of all files.
 *
 * Should this software be modified, the words "Modified from 
 * Original" must be included as a comment below this notice.
 *
 * All publication rights are retained.  This software or its 
 * documentation may not be published in any media either in whole
 * or in part without explicit permission.
 *
 * Contact information:
 *   Richard Rasala    rasala@ccs.neu.edu
 *   Viera Proulx      vkp@ccs.neu.edu
 *   Jeff Raab         jmr@ccs.neu.edu
 * 
 * Telephone:          617-373-2462
 *
 * This software was created with support from Northeastern 
 * University and from NSF grant DUE-9950829.
 */


import edu.neu.ccs.*;
import edu.neu.ccs.gui.*;
import edu.neu.ccs.util.*;
import java.awt.*;
import javax.swing.*;

/**
 * <P>Main application class for testing simple time.</P>
 *
 * @author Richard Rasala
 */
public class CircleTester
    extends TablePanel
    implements JPTConstants
{

    ///////////////
    // Constants //
    ///////////////
    

    
    /////////////////
    // Member Data //
    /////////////////
    
    // BufferedPanel(int width, int height, Paint background)
    protected BufferedPanel graphicsPane =
        new BufferedPanel(400, 400, Color.white);
    
    // text fields views
    // TextFieldView
    //     (String text, String errorPrompt, String dialogTitle, int width)
    
    protected TextFieldView radiusTFV =
        new TextFieldView("", "Radius Error", "Input Error", 120);
    
    protected TextFieldView xTFV =
        new TextFieldView("", "X Error", "Input Error", 120);
    
    protected TextFieldView yTFV =
        new TextFieldView("", "Y Error", "Input Error", 120);
    
    // TablePanel(Object[][] contents, int hgap, int vgap, int align)
    
    protected TablePanel inputFields =
        new TablePanel(
            new Object[][] {
                { "Radius", radiusTFV },
                { "X",      xTFV      },
                { "Y",      yTFV      }
            },
            5, 5, SOUTH_EAST
        );
    
    // actions--->buttons
    
    protected SimpleAction drawAction =
        new SimpleAction("Draw") {
            public void perform() { drawAction(); }
        };
    
    protected SimpleAction fillAction =
        new SimpleAction("Fill") {
            public void perform() { fillAction(); }
        };
    
    // actions panel
    // ActionsPanel(Action[] actions, LayoutManager layout)
    
    protected ActionsPanel buttons =
        new ActionsPanel (
            new Action[] { drawAction, fillAction },
            new TableLayout(2, 1, 5, 5, NORTH)
        );
        
    // controls
    // TablePanel
    // (Object[] contents, int orientation, int hgap, int vgap, int align)
    
    protected TablePanel controls =
        new TablePanel(
            new Object[] {
                inputFields,
                buttons
            },
            VERTICAL, 5, 5, NORTH
        );
    
    /////////////////
    // Constructor //
    /////////////////
    
    //TablePanel(int rows, int cols, int hgap, int vgap, int align) 
    public CircleTester() {
        super(1, 2, 5, 5, NORTH);
        
        buildGUI();
    }
        
    //////////////////////
    // Member Functions //
    //////////////////////
    
    protected void buildGUI() {
        add(controls);
        add(graphicsPane);
    }

    protected void drawAction() {
        // Get data from GUI
        double radius = radiusTFV.demandDouble();
        double x = xTFV.demandDouble();
        double y = yTFV.demandDouble();
        
        Circle C = new Circle(radius, x, y);
        
        C.draw(graphicsPane.getBufferGraphics());
        graphicsPane.repaint();
    }
    
    protected void fillAction() {
        try {
            // Get data from GUI
            double radius = radiusTFV.requestDouble();
            double x = xTFV.requestDouble();
            double y = yTFV.requestDouble();
            
            Circle C = new Circle(radius, x, y);
            
            C.fill(graphicsPane.getBufferGraphics());
            graphicsPane.repaint();
        }
        catch (CancelledException ex) { }
    }
    
    //////////
    // main //
    //////////
    
    /** The main program to launch the simple time test. */
    public static void main(String[] args) {
        JPTFrame.createQuickJPTFrame
            ("Circle Tester", new CircleTester());
    }
}